@@ -17,14 +17,14 @@
 import sys
 import re
 import glob
-from calculate.lib.cl_template import TemplateFormat
+from ..cl_template import TemplateFormat
 
-from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.common import getTupleVersion
-from calculate.lib.utils.content import PkgContents
-from calculate.lib.utils.portage import getInstalledAtom
-from calculate.lib.utils.files import pathJoin
-from calculate.lib.utils.tools import classificate
+from ..cl_lang import setLocalTranslate
+from ..utils.common import getTupleVersion
+from ..utils.content import PkgContents
+from ..utils.portage import getInstalledAtom
+from ..utils.files import pathJoin
+from ..utils.tools import classificate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
