@@ -795,17 +795,21 @@ def makeDirectory(pathname, force=False):
         return False
 
 
-def readLinesFile(filename, grab=False):
+def readLinesFile(filename, grab=False, binary=False):
     """Read file by line"""
+    mode = 'rb' if binary else 'r'
+    encoding = None if binary else 'utf-8'
+    startsymbol = b'#' if binary else "#"
+    line_break = b'\n' if binary else '\n'
     try:
         if path.exists(filename):
-            for line in open(filename, 'r', encoding='utf-8'):
+            for line in open(filename, mode, encoding=encoding):
                 if grab:
                     line = line.strip()
-                    if not line.startswith("#"):
+                    if not line.startswith(startsymbol):
                         yield line
                 else:
-                    yield line.rstrip('\n')
+                    yield line.rstrip(line_break)
     except (OSError, IOError):
         pass
     # finally:
